@@ -21,6 +21,7 @@
 #include "tilda_terminal.h"
 #include "configsys.h"
 #include "wizard.h" /* wizard */
+#include "vte-util.h"
 
 #include <stdio.h>
 #include <stdlib.h> /* malloc */
@@ -31,7 +32,10 @@
 #include <vte/vte.h>
 #include <string.h>
 
-#define HTTP_REGEXP "(ftp|http)s?://[\\[\\]-a-zA-Z0-9.?!$%&/=_~#.,:;+]*"
+#define PCRE2_CODE_UNIT_WIDTH 0
+#include <pcre2.h>
+
+#define HTTP_REGEXP "(ftp|http)s?://[\\[\\]-a-zA-Z0-9.?@!$%&/=_~#.,:;+]*"
 
 static void start_shell (tilda_term *tt, gboolean ignore_custom_command);
 static void start_default_shell (tilda_term *tt);
@@ -67,39 +71,22 @@ gint tilda_term_free (tilda_term *term)
     g_clear_object (&term->scrollbar);
     g_clear_object (&term->vte_term);
 
-    g_regex_unref (term->http_regexp);
+    if (term->http_regexp != NULL) {
+        g_regex_unref (term->http_regexp);
+    }
+
+    if (term->vte_regexp != NULL) {
+        vte_regex_unref (term->vte_regexp);
+    }
 
     term->http_regexp = NULL;
+    term->vte_regexp = NULL;
 
     g_free (term);
 
     return 0;
 }
 
-static void tilda_terminal_switch_page_cb (GtkNotebook *notebook,
-                                           GtkWidget   *page,
-                                           guint        page_num,
-                                           tilda_window *tw)
-{
-    DEBUG_FUNCTION ("tilda_terminal_switch_page_cb");
-    guint counter = 0;
-    tilda_term *term = NULL;
-    for(GList *item=tw->terms; item != NULL; item=item->next) {
-        if(counter == page_num) {
-            term = (tilda_term*) item->data;
-        }
-        counter++;
-    }
-
-    char * current_title = tilda_terminal_get_title (term);
-
-    if (current_title != NULL) {
-        gtk_window_set_title (GTK_WINDOW (tw->window), current_title);
-    }
-
-    g_free (current_title);
-}
-
 struct tilda_term_ *tilda_term_init (struct tilda_window_ *tw)
 {
     DEBUG_FUNCTION ("tilda_term_init");
@@ -185,12 +172,22 @@ struct tilda_term_ *tilda_term_init (struct tilda_window_ *tw)
                       G_CALLBACK(refresh_window_cb), tw->window);
     g_signal_connect (G_OBJECT(term->vte_term), "move-window",
                       G_CALLBACK(move_window_cb), tw->window);
-    g_signal_connect (G_OBJECT (tw->notebook), "switch-page",
-                      G_CALLBACK (tilda_terminal_switch_page_cb), tw);
 
     /* Match URL's, etc */
-    term->http_regexp=g_regex_new(HTTP_REGEXP, G_REGEX_CASELESS, G_REGEX_MATCH_NOTEMPTY, &error);
-    ret = vte_terminal_match_add_gregex(VTE_TERMINAL(term->vte_term), term->http_regexp,0);
+    if (VTE_CHECK_VERSION_RUMTIME (0, 56, 1)) {
+        term->vte_regexp = vte_regex_new_for_match (HTTP_REGEXP, -1,
+                                                    PCRE2_CASELESS | PCRE2_MULTILINE,
+                                                    &error);
+
+        ret = vte_terminal_match_add_regex (VTE_TERMINAL(term->vte_term), term->vte_regexp,
+                                            PCRE2_NOTEMPTY);
+    } else {
+        term->http_regexp = g_regex_new (HTTP_REGEXP, G_REGEX_CASELESS,
+                                         G_REGEX_MATCH_NOTEMPTY, &error);
+        ret = vte_terminal_match_add_gregex (VTE_TERMINAL(term->vte_term),
+                                             term->http_regexp, 0);
+    }
+
     vte_terminal_match_set_cursor_type (VTE_TERMINAL(term->vte_term), ret, GDK_HAND2);
 
     /* Show the child widgets */
@@ -851,6 +848,14 @@ static void on_popup_hide (GtkWidget *widget, tilda_window *tw)
     tw->disable_auto_hide = FALSE;
 }
 
+static void
+on_selection_done (GtkWidget *widget, tilda_window *tw)
+{
+    DEBUG_FUNCTION ("on_selection_done");
+
+    gtk_menu_detach (GTK_MENU (widget));
+}
+
 static void
 popup_menu (tilda_window *tw, tilda_term *tt, GdkEvent * event)
 {
@@ -905,8 +910,12 @@ popup_menu (tilda_window *tw, tilda_term *tt, GdkEvent * event)
     /* Disable auto hide */
     tw->disable_auto_hide = TRUE;
     g_signal_connect (G_OBJECT(menu), "unmap", G_CALLBACK(on_popup_hide), tw);
+    g_signal_connect (G_OBJECT (menu), "selection-done", G_CALLBACK (on_selection_done), tw);
 
     gtk_menu_popup_at_pointer (GTK_MENU (menu), event);
+
+    g_object_unref (action_group);
+    g_object_unref (builder);
 }
 
 static int button_press_cb (G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event, gpointer data)
